==> julia-git-delaydiffeq-src-5.62.0-1-any.pkg.tar.zst: usr/share/julia/arch-site/DelayDiffEq/test/interface/default_solver.jl <==
using DelayDiffEq, OrdinaryDiffEqDefault, OrdinaryDiffEqCore, Test

# Simple DDE problem for testing
function f!(du, u, h, p, t)
    du[1] = -h(p, t - 0.2)[1]
end

h(p, t) = [0.0]
tspan = (0.0, 1.0)
prob = DDEProblem(f!, [1.0], h, tspan; constant_lags = [0.2])

# Note: DefaultODEAlgorithm with its DefaultCache structure is not yet fully compatible
# with DelayDiffEq's internal cache handling. This test verifies that the dispatch works
# but the full solving may encounter issues with the cache structure.

# Test that the dispatch is correctly defined
# The solve will encounter cache compatibility issues but should dispatch correctly
dispatch_works = try
    sol = SciMLBase.__solve(prob; maxiters = 1, verbose = false)
    true
catch e
    # Check if it's the expected cache error
    occursin("UndefRefError", string(e)) || occursin("DefaultCache", string(e))
end
@test dispatch_works

# Similarly for init
init_dispatch_works = try
    integrator = SciMLBase.__init(prob; maxiters = 1)
    true
catch e
    # Check if it's the expected cache error
    occursin("UndefRefError", string(e)) || occursin("DefaultCache", string(e))
end
@test init_dispatch_works

# For now, we can verify that explicitly using the algorithm creates the right structure
alg = MethodOfSteps(DefaultODEAlgorithm())
@test alg isa MethodOfSteps
@test alg.alg isa CompositeAlgorithm

# The actual solving with DefaultODEAlgorithm requires further compatibility work
# between DelayDiffEq and the DefaultCache structure from OrdinaryDiffEqDefault

==> julia-git-delaydiffeq-src-5.67.1-1-any.pkg.tar.zst: usr/share/julia/arch-site/DelayDiffEq/test/interface/default_solver.jl <==
using DelayDiffEq, OrdinaryDiffEqDefault, OrdinaryDiffEqCore, Test

# Simple DDE problem for testing
function f!(du, u, h, p, t)
    return du[1] = -h(p, t - 0.2)[1]
end

h(p, t) = [0.0]
tspan = (0.0, 1.0)
prob = DDEProblem(f!, [1.0], h, tspan; constant_lags = [0.2])

# Note: DefaultODEAlgorithm with its DefaultCache structure is not yet fully compatible
# with DelayDiffEq's internal cache handling. This test verifies that the dispatch works
# but the full solving may encounter issues with the cache structure.

# Test that the dispatch is correctly defined
# The solve will encounter cache compatibility issues but should dispatch correctly
dispatch_works = try
    sol = SciMLBase.__solve(prob; maxiters = 1)
    true
catch e
    # Check if it's the expected cache error
    occursin("UndefRefError", string(e)) || occursin("DefaultCache", string(e))
end
@test dispatch_works

# Similarly for init
init_dispatch_works = try
    integrator = SciMLBase.__init(prob; maxiters = 1)
    true
catch e
    # Check if it's the expected cache error
    occursin("UndefRefError", string(e)) || occursin("DefaultCache", string(e))
end
@test init_dispatch_works

# For now, we can verify that explicitly using the algorithm creates the right structure
alg = MethodOfSteps(DefaultODEAlgorithm())
@test alg isa MethodOfSteps
@test alg.alg isa CompositeAlgorithm

# The actual solving with DefaultODEAlgorithm requires further compatibility work
# between DelayDiffEq and the DefaultCache structure from OrdinaryDiffEqDefault
